cleanupdeletedusers

package
v0.0.0-...-2da20e2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 16, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Package cleanupdeletedusers ...

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Job

type Job struct{}

Job implements the worker.Job interface for cleaning up deleted user accounts.

func NewJob

func NewJob() *Job

NewJob ...

func (Job) Do

func (w Job) Do(ctx context.Context, s *service.Service, _ *app.DB) (err error)

Do executes the job's task, which is cleanup users data who have been soft-deleted for more than a certain period.

func (Job) Name

func (w Job) Name() string

Name returns the unique name of the job.

func (Job) Schedule

func (w Job) Schedule() gocron.JobDefinition

Schedule defines when the job should run. This job is scheduled to run once daily at midnight.

Jump to