Documentation
¶
Overview ¶
Package cleanupdeletedusers ...
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Job ¶
type Job struct{}
Job implements the worker.Job interface for cleaning up deleted user accounts.
func (Job) Do ¶
Do executes the job's task, which is cleanup users data who have been soft-deleted for more than a certain period.
func (Job) Schedule ¶
func (w Job) Schedule() gocron.JobDefinition
Schedule defines when the job should run. This job is scheduled to run once daily at midnight.
Click to show internal directories.
Click to hide internal directories.